pub struct PackedReader<'de, 'src, N: NestedValue, Dec: DomainDecode<N::Embedded>, S: BinarySource<'de>> {
pub source: &'src mut S,
pub decode_embedded: Dec,
/* private fields */
}Expand description
The binary encoding Preserves reader.
Fields
source: &'src mut SUnderlying source of bytes.
decode_embedded: DecDecoder for producing Rust values embedded in the binary data.
Implementations
Sourceimpl<'de, 'src, N: NestedValue, Dec: DomainDecode<N::Embedded>, S: BinarySource<'de>> PackedReader<'de, 'src, N, Dec, S>
impl<'de, 'src, N: NestedValue, Dec: DomainDecode<N::Embedded>, S: BinarySource<'de>> PackedReader<'de, 'src, N, Dec, S>
Sourcepub fn new(source: &'src mut S, decode_embedded: Dec) -> Self
pub fn new(source: &'src mut S, decode_embedded: Dec) -> Self
Construct a new reader from a byte source and embedded-value decoder.